﻿# -*- coding: utf-8 -*-
# Module: default
# Author: malvinas2
# Created on: 28.01.2017
# License: GPL v.3 https://www.gnu.org/copyleft/gpl.html

# version 1.0.2

#################################################################################
# Special thanks go to:                                                         #
#                                                                               #
# beardypig for the streamlink-support                                          #
# Roman_V_M aka Roman Miroshnychenko for his great tutorial about video add-ons #
# enraged from kodimania.com, also for his excellent tutorial                   #
# Ulises Gascón for his documentation of the rtve.es API                        #
#                                                                               #
#################################################################################


#from __future__ import unicode_literals
import sys
import os.path
from urllib import urlencode
from urlparse import parse_qsl
from Common import logger
from Common import tools
import re
import xbmcgui
import xbmcplugin
import xbmcaddon
import xbmc
import urlparse
import json
import urllib
from bs4 import BeautifulSoup
import streamlink



# import rpdb2 
# rpdb2.start_embedded_debugger('pw')

# Get the plugin url in plugin:// notation.
_url = sys.argv[0]
# Get the plugin handle as an integer number.
addon_handle = int(sys.argv[1])    # what would be the advantage using underscore: _handle ??

addon = xbmcaddon.Addon()
addonname = addon.getAddonInfo('name')

series_domain_1 = "http://www.rtve.es/modulos/navtabs?active="
series_domain_2 = "&class=&type=tabs&feed=/television/forms/listado-programas-series.inc"



def get_url(**kwargs):
    """
    Create a URL for calling the plugin recursively from the given set of keyword arguments.

    :param kwargs: "argument=value" pairs
    :type kwargs: dict
    :return: plugin call URL
    :rtype: str
    """
    return '{0}?{1}'.format(_url, urlencode(kwargs))


    
    
def list_menu_principal(menu_tipo):
    ##### defines the main menu plus three submenus (documentation, series and a-z listing)
    if menu_tipo == "menu_general": 
        entries = {"42273" : "Archivo", "42172" : "Ciencia y Tecnología", "42173" : "Cine", "42274" : "Concursos", "42190" : "Cultura", "42191" : "Deportes", "42171" : "Documentales", "42271" : "Educación", "42251" : "Humor", "42431" : "Infantiles", "39814" : "Informativos", "42210" : "Magacín", "42192" : "Música", "42230" : "Otros Programas", "57334" : "Recetas", "42170" : "Series", "42272" : "Viajes", "11111": "[A-Z] Listado de programas"}
        programa = "normal"
    elif menu_tipo == "menu_docu": 
        entries = {"70131" : "Actualidad", "70130" : "Artes", "70099" : "Biografías", "70100" : "Ciencia y tecnología", "70117" : "Culturas", "70132" : "Deportes", "70133" : "Gastronomía", "70098" : "Historia", "70097" : "Naturaleza", "70116" : "Viajes"}
        programa = "docu"
    elif menu_tipo == "menu_series": 
        entries = {"GE_ACYAVET" : "Acción y aventuras", "IN_EMISSION" : "En Emisión", "GE_INFAN" : "Infantil", "GE_COMED" : "Comedia", "GE_DRAMA" : "Drama", "GE_SOMESA" : "Sobremesa", "GE_TVMOVI" : "TV Movies", "GE_POYDSUS" : "Policíacas y de suspense", "GE_SERHIS" : "Series Históricas", "GE_SERLIT" : "Series Literarias", "GE_SERCAT" : "Series en Catalán", "ALL" : "Todas"}
        programa = "serie"
    elif menu_tipo == "menu_az": 
        entries = {"%23" : "0-9", "A" : "A", "B" : "B", "C" : "C", "D" : "D", "E" : "E", "F" : "F", "G" : "G", "H" : "H", "I" : "I", "J" : "J", "K" : "K", "L" : "L", "M" : "M", "N" : "N", "O" : "O", "P" : "P", "Q" : "Q", "R" : "R", "S" : "S", "T" : "T", "U" : "U", "V" : "V", "W" : "W", "X" : "X", "Y" : "Y", "Z" : "Z"}
        programa = "az"
    is_folder = True
    for key in entries:
        list_item = xbmcgui.ListItem(label=entries[key])
        list_item.setInfo('video', {'title': entries[key]})
        myurl = tools.build_url({'action':'submenu','category':programa,'agr_id':key, 'page': '1', 'position': '0'})
        xbmcplugin.addDirectoryItem(addon_handle, myurl, list_item, is_folder)
    xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_LABEL_IGNORE_THE)
    xbmcplugin.endOfDirectory(addon_handle)     

 
   
def list_menu_episodes1(programa_id, programa_titulo, programa_description, programa_thumbnail, programa_logo, programa_background, programa_poster, programa_date):
    ### the API doesn't seem to allow to distinguish between the different types of videos: 'cualquiera', 'reportaje', 'fragmento', 'avance', 'entrevista' or 'complete', so we have to distinguish manually between 'complete' and other kind of types. 
    ### !!! The addon will just show 'complete' episodes.  !!!
    ### exception: seasons ('temporadas') normally just contain 'complete' videos, so we can show them immediately using the API
    
    
    referer = "http://www.rtve.es/television/series-tve/"

    # ==== no seasons available, pseudo-seasons are generated =======
    temporada_id = '9999'
    # ======= number of capitulos shown per pseudo-season / pageSize
    CAPITULO_PAGE = 25
    
    # ======== find number of total capitulos emittido hasta ahora ===== capitulo_total
    myurl = "http://www.rtve.es/alacarta/filterVideoSlide.shtml?ctx=" + str(programa_id) + "&pageSize=1"
    html = tools.getUrl2(myurl, referer)
    soup = BeautifulSoup(html)
    try: 
        div = soup.find("span").text
        pattern = '\((.*?)\)'
        capitulo_total = tools.findall(pattern,div, re.DOTALL)[0]
    except:                   # ====== sometimes there a no complete episodes available, e.g. 'Los misterios de Laura (version americana)'
        capitulo_total = '0'  # ====== and the whole page ../filterVideoSlide.shtml/... is completely empty
        
    
    # myurl = "http://www.rtve.es/alacarta/interno/contenttable.shtml?pbq=1&orderCriteria=DESC&modl=TOC&locale=es&pageSize=1&ctx=" + programa_id + "&typeFilter=39816"
    # html = tools.getUrl2(myurl, referer)
    # soup = BeautifulSoup(html)
    # div = soup.find_all("h2")
    # capitulo_total = div[0].text.encode('utf-8')
    # capitulo_total_regex = re.compile(r'\d+')
    # capitulo_total = capitulo_total_regex.search(capitulo_total).group(0)

    
    capitulo_total = int(capitulo_total)
    capitulo_sectiones = capitulo_total / CAPITULO_PAGE
    capitulo_resto = capitulo_total % CAPITULO_PAGE
    
    capitulo_section_label = []
    capitulo_section_id = []
  
    if capitulo_total == 0: 
        xbmcgui.Dialog().ok(addonname, "Ningun contenido está disponible. ")
    # sometimes the content just is available for a few days because of legal reasons or there are no complete episodes available at all    
    
    elif (capitulo_total > 30): 
        for i in range(0, (capitulo_sectiones)):
            temp = "Capítulo " +  str(capitulo_total - (i + 1) * CAPITULO_PAGE + 1) + " - " +  str(capitulo_total - i * CAPITULO_PAGE)
            capitulo_section_label.append(temp)
            capitulo_section_id.append(i)
        end_of_index = capitulo_sectiones
        if capitulo_resto > 0: 
            temp = "Capítulo 1 - " + str(capitulo_resto)
            #"Capítulo " + str(capitulo_sectiones * CAPITULO_PAGE + 1) + " - " + str(capitulo_sectiones * CAPITULO_PAGE + capitulo_resto)
            capitulo_section_label.append(temp)
            capitulo_section_id.append(capitulo_sectiones)
        #capitulo_section_id.reverse()
            end_of_index = capitulo_sectiones + 1
        flag = 3
 
        for i in range(0, (end_of_index)): 
            myurl = tools.build_url({'action':'temporada', 'programa_id':programa_id, 'programa_thumbnail':programa_thumbnail, 'programa_logo':programa_logo, 'programa_background':programa_background, 'programa_poster':programa_poster, 'flag': flag, 'capitulo_total':capitulo_total, 'temporada_id': capitulo_section_id[i]})
            list_item = xbmcgui.ListItem(label=capitulo_section_label[i])
            list_item.setArt({'thumb': programa_thumbnail, 'fanart': programa_background, 'poster': programa_poster, 'clearlogo': programa_logo})
            list_item.setInfo('video', {'title': programa_titulo, 'plot': programa_description})
            list_item.setProperty('IsPlayable', 'false')
            xbmcplugin.addDirectoryItem(handle = addon_handle, url = myurl, listitem = list_item, isFolder= True)           
        xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_VIDEO_TITLE)
        xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_LABEL_IGNORE_THE)
        xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_DATE)
        xbmcplugin.endOfDirectory(addon_handle) 

    elif capitulo_total <= 30: 
        flag = 2
        capitulo_total = 0
        return list_menu_episodes2(programa_id, programa_thumbnail, programa_logo, programa_background, programa_poster, flag, capitulo_total, temporada_id)

    

def list_menu_episodes2(programa_id, programa_thumbnail, programa_logo, programa_background, programa_poster, flag, capitulo_total, temporada_id):    
    referer = "http://www.rtve.es/alacarta/videos/" 
    
    ### the API doesn't seem to allow to distinguish between the different types of videos: 'cualquiera', 'reportaje', 'fragmento', 'avance', 'entrevista' or 'complete', so we have to distinguish manually between 'complete' and other kind of types. 
    ### !!! The addon will just show 'complete' episodes.  !!!
    ### exception: seasons ('temporadas') normally just contain 'complete' videos, so we can show them immediately using the API
    
    ### Attention: Name of variables are different than the ones used within xxxy, although they've got the same function, I should change that one rainy day.....
    
    flag = int(flag)
    temporada_id = int(temporada_id)
    # flag = 1: seasons available
    #      = 2: no seasons available, total nr. of episodes < 31
    #      = 3: no seasons available, total nr. > 31, virtual seasons are created
    if (flag == 1) or (flag == 2) or (flag == 3): 
        if flag == 2: 
            tempurl = "http://www.rtve.es/alacarta/filterVideoSlide.shtml?ctx=" + str(programa_id) + "&pageSize=50"
            tempurl2 = "http://www.rtve.es/alacarta/interno/contenttable.shtml?ctx=" + str(programa_id) + "&locale=es&module=&orderCriteria=DESC&pageSize=50&mode=TEXT&typeFilter=39816"  ##### typeFilter: 39978 = Fragmento, 39979 = Reportaje, 39816 = Completo, 39978 = Fragmento, 39980 = Avance, 39981 = Entrevista
        
        elif flag == 3: 
            CAPITULO_PAGE = 25
            capitulo_total = int(capitulo_total)
            capitulo_sectiones = capitulo_total / CAPITULO_PAGE
            capitulo_resto = capitulo_total % CAPITULO_PAGE
            tempurl = "http://www.rtve.es/alacarta/filterVideoSlide.shtml?ctx=" + str(programa_id) + "&paginaBusqueda=" + str(temporada_id+1) + "&pageSize=" + str(CAPITULO_PAGE)
            tempurl2 = "http://www.rtve.es/alacarta/interno/contenttable.shtml?ctx=" + str(programa_id) + "&pbq=" + str(temporada_id+1) + "&locale=es&module=&orderCriteria=DESC&pageSize=" + str(CAPITULO_PAGE) + "&mode=TEXT&typeFilter=39816"
        
        # the above two URLs are necessary, because one of them lists all videos with their title, aired date and _thumbnail_, whereas the other one lists the videos containing title, aired date and _plot description_
        # the number of the entries of both URLs should be the same, otherwise we are running in problems... 
        
        
        html = tools.getUrl2(tempurl, referer)
        soup = BeautifulSoup(html)
        html2 = soup.find_all("span", class_="img")
    
        capitulo_imagen = []   # http://img.rtve.es/imagenes/olmos-robles-capitulo-7-juego-almanzor/1445372948265.jpg'
        capitulo_id = []       # 3329299
        capitulo_url = []      # /alacarta/videos/olmos-y-robles/olmos-robles-capitulo-7-juego-almanzor/3329299/
        for i in range(len(html2)):
            temp = html2[i].find('img')['src']
            capitulo_imagen.append(temp)
            temp = html2[i].find('a')['id']
            capitulo_id.append(temp)
            temp = "http://www.tve.es" + html2[i].find('a')['href']
            capitulo_url.append(temp)
    

        html = tools.getUrl2(tempurl2, referer)
        soup = BeautifulSoup(html)
    
        capitulo_titulo = []      # Cap\xc3\xadtulo 7 - El juego de Almanzor
        capitulo_duracion = []    # 1:11:56
        capitulo_fecha = []       # 27 oct 2015
        capitulo_detalle = []     # Ha llegado la hora de la verdad y Olmos y Robles descubren 
                                  # que el psic\xf3pata que se esconde tras el seud\xf3nimo de Almanzor es alguien
                                  # a quien conocen muy bien. Y lo peor de todo es que ahora esta pare...
    
        ct = soup.find_all("span", class_="titulo-tooltip")
        cdur = soup.find_all("span", class_="col_dur") # duration of video
        cdur[0].decompose()
        cdur = soup.find_all("span", class_="col_dur")
        cf = soup.find_all("span", class_="fecha") # date of tv-aired
        cd = soup.find_all("span", class_="detalle") # description of episode

        miga = soup.find_all("span", class_="miga")   #################
        
        len2 = len(ct)
        # pattern = 'title=\"(.*?)\"'
        for i in range(len(ct)):
            #if miga[i].find("a").text.encode('utf-8') == 'Televisi\xc3\xb3n': ############## 
            if ct[i].find('a')['href'][10:16] == 'videos': ###### 'if' necessary because there are sometimes, in rare cases audio media within the video section
                                                           ###### examples: Ciencia forense, 30 anios sin Felix, Eurovision 2014
                                                           ###### this work-around just works as long as the number of episodes is smaller than 25 (?)
                                                           ###### for example in case of "Eurovsion 2014" it doesn't work-around
                                                           ###### just very few programs show this behaviour, so probably I won't improve this
                #===== extract episode title ====
                temp = ct[i].text.encode('utf-8')
                capitulo_titulo.append(temp)  
                #===== extract duration of video ====
                temp = cdur[i].text.encode('utf-8')
                temp = tools.get_sec(temp)
                capitulo_duracion.append(temp)  
                #===== extract date of tv-aired ====
                temp = cf[i].text.encode('utf-8')
                temp = tools.fecha_to_date(temp)
                capitulo_fecha.append(temp)    
                #==== extract description of episode ====
                temp = cd[i].text.encode('utf-8')
                capitulo_detalle.append(temp)
            else: 
                pass

        # programa_poster2 = []
        # if tools.getSetting("thumbposter") == 'true': 
            # for i in range(len(html2)): 
                # programa_poster[i] = capitulo_imagen[i]
        # else: 
            # for i in range(len(html2)): 
                # programa_poster2[i] = programa_poster        
                
        for i in range(len(html2)):    ###############
            myurl = tools.build_url({'action':'play_video','capitulo_id':capitulo_id[i]})
            list_item = xbmcgui.ListItem(label=capitulo_titulo[i])
            if tools.getSetting("thumbposter") == 'true':
                list_item.setArt({'thumb': capitulo_imagen[i], 'poster': capitulo_imagen[i], 'fanart': programa_background, 'clearlogo': programa_logo, 'icon': capitulo_imagen[i]})
            else:
                 list_item.setArt({'thumb': capitulo_imagen[i], 'poster': programa_poster, 'fanart': programa_background, 'clearlogo': programa_logo, 'icon': capitulo_imagen[i]})
            list_item.setInfo('video', {'title': capitulo_titulo[i], 'plot': capitulo_detalle[i], 'duration': capitulo_duracion[i], 'aired': capitulo_fecha[i], 'premiered': capitulo_fecha[i]})
            list_item.setProperty('IsPlayable', 'true')
            xbmcplugin.addDirectoryItem(handle = addon_handle, url = myurl, listitem = list_item, isFolder= False)
            #xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_NONE)
            #xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_UNSORTED)
        xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_VIDEO_TITLE)
        xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_LABEL_IGNORE_THE)
        xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_DATE)
        xbmcplugin.endOfDirectory(addon_handle) 

 
def list_menu_agrupadores(tipo, agr_id, page, position):
    #### shows the list of available programs of the selected submenu
    referer = "http://www.rtve.es/television/"
    if tipo == "normal": 
        url = "http://www.rtve.es/api/agrupadores/" + str(agr_id) + "/programas.xml?"
    elif tipo == "docu": 
        url = "http://www.rtve.es/api/agrupadores/" + str(agr_id) + "/programas.xml?"
    elif tipo == "az": 
        url = "http://www.rtve.es/api/programas.xml?startWithLetter=" + str(agr_id) + "&"
    ##### in case of series: 
    else: 
        if agr_id == "IN_EMISSION":
            url = "http://www.rtve.es/api/programas.xml?genero=ALL&emiStatus=IN_EMISSION&order=title,asc&"
        else: 
            url = "http://www.rtve.es/api/programas.xml?genero=" + str(agr_id) + "&"
    
    url2 = url + "page=1&size=60"
    html = tools.getUrl2(url2, referer)
    soup = BeautifulSoup(html)
    div = soup.find('items')
    
    pagina_actual = int(soup.find('number').text)
    pagina_total = int(soup.find('totalpages').text)

    programa_id = []
    programa_titulo = []
    programa_descripcion = []
    programa_thumbnail = []
    programa_logo = []
    programa_background = []
    programa_poster = []
    programa_date = []
    
    
    position = int(position)
    page = int(page)
    index = 0
    index2 = 0
    
    while (index < 25) and (page <= pagina_total): 
        
        url2 = url + "page=" + str(page) + "&size=60"
        html = tools.getUrl2(url2, referer)
        soup = BeautifulSoup(html)
        div = soup.find('items')
        
        liste = []        
        for count, child in enumerate(div.children):
            liste.append(child)
    
        for i in range(position, len(liste)):
            position = position + 1
            #### the API doesn't allow to distinguish between 'videos' or 'radio'-stuff, we have to do this manually
            #### 'series' and 'documentation' just contain videos, so the verification within the if-clause could be skipped, 
            #### nevertheless I kept them in because of laziness....
            if liste[i].htmlurl.text[28:34] == 'videos': 
                temp = str(liste[i].find('id').text)
                programa_id.append(temp)
            
                temp = (liste[i].find('shorttitle').text.encode('utf-8'))
                temp = re.sub("&apos;", "'", temp)
                programa_titulo.append(temp)
            
                try:
                    temp = (liste[i].find('description').text.encode('utf-8'))
                    temp = temp[9:-3]
                    temp = re.sub("&apos;", "'", temp)
                    programa_descripcion.append(temp)
                except:
                    temp = ' '
                    programa_descripcion.append(temp)
                
                temp = (liste[i].find('thumbnail').text)
                programa_thumbnail.append(temp)
                
                temp = (liste[i].find('logo').text)
                programa_logo.append(temp)
                
                temp = (liste[i].find('publicationdate').text)
                temp = temp[0:10]
                temp = temp.split("-")
                temp = temp[2] + "-" + temp[1] + "-" + temp[0]
                programa_date.append(temp)
                
                temp = (liste[i].find('imgbackground').text)
                programa_background.append(temp)
                
                temp = (liste[i].find('imgposter').text)
                programa_poster.append(temp)
                
                if not programa_background[len(programa_background)-1]:
                    #if tools.getSetting("fanposter") == "false": 
                    programa_background[len(programa_background)-1] = programa_poster[len(programa_background)-1]

                index2 = index2 + 1 
                if index2 >= 25: 
                    break
                else: 
                    pass
            else: 
                pass
            
        pagina_actual = page
        page = page +1
        index = index2
        position_alt = position
        position = 0

    for i in range(len(programa_id)):
        myurl = tools.build_url({'action':'agrup2', 'programa_id':programa_id[i], 'programa_titulo':programa_titulo[i], 'programa_description':programa_descripcion[i], 'programa_thumbnail':programa_thumbnail[i], 'programa_logo': programa_logo[i], 'programa_background': programa_background[i], 'programa_poster':programa_poster[i], 'programa_date': programa_date[i]})
        # , 'serie_description':description[i]
        list_item = xbmcgui.ListItem(label=programa_titulo[i])
        list_item.setArt({'thumb': programa_thumbnail[i] , 'fanart': programa_background[i], 'clearlogo': programa_logo[i], 'poster': programa_poster[i]})
        list_item.setInfo('video', {'title': programa_titulo[i], 'plot': programa_descripcion[i], 'aired': programa_date[i], 'premiered': programa_date[i]})
        list_item.setProperty('IsPlayable', 'false')
        xbmcplugin.addDirectoryItem(handle = addon_handle, url = myurl, listitem = list_item, isFolder= True)
    if pagina_actual < pagina_total: 
        label_str2 = "<-- Volver al menú principal"
        list_item = xbmcgui.ListItem(label=label_str2)
        myurl = tools.build_url({'action':'menu_general', 'category':'menu_general', 'agr_id':agr_id, 'page':'1', 'position':'0'})
        xbmcplugin.addDirectoryItem(handle = addon_handle, url = myurl, listitem = list_item, isFolder= True) 
        label_str = "--> Pagina siguiente"
        list_item = xbmcgui.ListItem(label=label_str)
        myurl = tools.build_url({'action':'submenu','category':tipo,'agr_id':agr_id, 'page': str(pagina_actual), 'position':str(position_alt)})
        xbmcplugin.addDirectoryItem(handle = addon_handle, url = myurl, listitem = list_item, isFolder= True)
      
    if (pagina_actual == pagina_total) and (position_alt < (len(liste)-1)): 
        label_str2 = "<-- Volver al menú principal"
        list_item = xbmcgui.ListItem(label=label_str2)
        myurl = tools.build_url({'action':'menu_general','category': 'menu_general', 'agr_id':agr_id, 'page': '1', 'position': '0'})
        xbmcplugin.addDirectoryItem(handle = addon_handle, url = myurl, listitem = list_item, isFolder= True)  
        label_str = "--> Pagina siguiente"
        list_item = xbmcgui.ListItem(label=label_str)
        myurl = tools.build_url({'action':'submenu','category':tipo,'agr_id':agr_id, 'page': str(pagina_actual), 'position':str(position_alt)})
        xbmcplugin.addDirectoryItem(handle = addon_handle, url = myurl, listitem = list_item, isFolder= True)

    xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_VIDEO_TITLE)
    xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_LABEL_IGNORE_THE)
    xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_DATE)
    xbmcplugin.endOfDirectory(addon_handle)       
    

    
def list_menu_agrupadores2(programa_id, programa_titulo, programa_description, programa_thumbnail, programa_logo, programa_background, programa_poster, programa_date):
    referer = "http://www.rtve.es/television/"
    url = "http://www.rtve.es/api/programas/" + str(programa_id) + "/temporadas.xml?size=60"
    
    html = tools.getUrl2(url, referer)
    soup = BeautifulSoup(html)        
    
    numero_temporadas = int(soup.numelements.text)
    
    temporada_id = []

    if numero_temporadas > 0:
        div = soup.find('items')
        liste = []
        for count, child in enumerate(div.children):
            liste.append(child)
 
        for i in range(len(liste)):
            temp = str(liste[i].find('id').text)
            temporada_id.append(temp)
        
        for i in range(len(liste)):
            myurl = tools.build_url({'action':'agrup3', 'programa_id':programa_id, 'programa_titulo':programa_titulo, 'programa_description':programa_description, 'programa_thumbnail':programa_thumbnail, 'programa_logo': programa_logo, 'programa_background': programa_background, 'programa_poster':programa_poster, 'programa_date': programa_date, 'temporada_id': temporada_id[i], 'page': '1'})
            list_item = xbmcgui.ListItem(label="Temporada "+str(i+1))
            list_item.setArt({'thumb': programa_thumbnail , 'fanart': programa_background, 'clearlogo': programa_logo, 'poster': programa_poster})
            list_item.setInfo('video', {'title': programa_titulo, 'plot': programa_description, 'aired': programa_date, 'premiered': programa_date})
            list_item.setProperty('IsPlayable', 'false')
            xbmcplugin.addDirectoryItem(handle = addon_handle, url = myurl, listitem = list_item, isFolder= True)            
        xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_VIDEO_TITLE)
        xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_LABEL_IGNORE_THE)
        xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_DATE)
        xbmcplugin.endOfDirectory(addon_handle)  
       
    else:
        list_menu_episodes1(programa_id, programa_titulo, programa_description, programa_thumbnail, programa_logo, programa_background, programa_poster, programa_date)

        
def list_menu_agrupadores3(programa_id, programa_titulo, programa_description, programa_thumbnail, programa_logo, programa_background, programa_poster, programa_date, temporada_id, page):
    referer = "http://www.rtve.es/television/"
    url = "http://www.rtve.es/api/programas/" + str(programa_id) + "/temporadas/" + str(temporada_id) + "/videos.xml"+ "?page=" + str(page)

    html = tools.getUrl2(url, referer)
    soup = BeautifulSoup(html)        
    div = soup.find('items')
    liste = []
    for count, child in enumerate(div.children):
        liste.append(child)   
        
    pagina_actual = int(soup.find('number').text)
    pagina_total = int(soup.find('totalpages').text)

    capitulo_titulo = []      # Cap\xc3\xadtulo 7 - El juego de Almanzor
    capitulo_duracion = []    # 1:11:56
    capitulo_fecha = []       # 27 oct 2015
    capitulo_detalle = []   
    capitulo_id = []
    capitulo_thumbnail = []
    
    for i in range(len(liste)):
        temp = str(liste[i].find('id').text)
        capitulo_id.append(temp)

        temp = (int(liste[i].find('duration').text))/1000
        capitulo_duracion.append(temp)
        
        temp = (liste[i].find('shorttitle').text.encode('utf-8'))
        capitulo_titulo.append(temp)

        try:
            temp = liste[i].find_all('description')
            temp = temp[1].text.encode('utf-8')
            temp = temp[9:-3]
            temp = re.sub("&apos;", "'", temp)
            temp = re.sub("<P>", "", temp)
            temp = re.sub("</P>", " ", temp)
            temp = re.sub("<p>", "", temp)
            temp = re.sub("</p>", " ", temp)
            temp = re.sub("&#160", "", temp)
            temp = re.sub("&oacute;", "ó", temp)
            temp = re.sub("&aacute;", "á", temp)
            temp = re.sub("&eacute;", "é", temp)
            temp = re.sub("&iacute;", "í", temp)
            temp = re.sub("&uacute;", "ú", temp)
            temp = re.sub("&iquest;", "¿", temp)
            temp = re.sub("&nbsp;", "", temp)
            temp = re.sub("&ntilde;", "ñ", temp)
            temp = re.sub(";<strong>", " ", temp)
            temp = re.sub("<strong>", " ", temp)
            temp = re.sub("</strong>", "", temp)
            temp = re.sub("&#39;", "'", temp)
            temp = re.sub("&ldquo;", ">", temp)
            temp = re.sub("&rdquo;", "<", temp)
            temp = re.sub("&lsquo;", ">", temp)
            temp = re.sub("&rsquo;", "<", temp)
            temp = re.sub("<br />", "", temp)
            temp = re.sub("<em>", "", temp)
            temp = re.sub("</em>", "", temp)
            temp = re.sub("<span(.*?)>", "", temp)
            temp = re.sub("<a href(.*?)>", "", temp)
            temp = re.sub("</a>;", " ", temp)
            capitulo_detalle.append(temp)
        except:
            temp = ' '
            capitulo_detalle.append(temp)
        
        temp = (liste[i].find('thumbnail').text)
        capitulo_thumbnail.append(temp)
                
        temp = (liste[i].find('publicationdate').text)
        temp = temp[0:10]
        temp = temp.split("-")
        temp = temp[2] + "-" + temp[1] + "-" + temp[0]
        capitulo_fecha.append(temp)

    if (pagina_actual < pagina_total):
        label_str2 = "<-- Volver al menú principal"
        list_item = xbmcgui.ListItem(label=label_str2)
        #myurl = tools.build_url({'action':'menu_general', 'category': 'menu_general', 'agr_id':agr_id, 'page': '1', 'position': '0'})
        myurl = tools.build_url({'action':'menu_general', 'category': 'menu_general'})
        xbmcplugin.addDirectoryItem(handle = addon_handle, url = myurl, listitem = list_item, isFolder= True)  
        label_str = "--> Pagina siguiente (" + str(pagina_actual+1) + "/" + str(pagina_total) + ")"
        list_item = xbmcgui.ListItem(label=label_str)
        myurl = tools.build_url({'action':'agrup3', 'programa_id':programa_id, 'programa_titulo':programa_titulo, 'programa_description':programa_description, 'programa_thumbnail':programa_thumbnail, 'programa_logo': programa_logo, 'programa_background': programa_background, 'programa_poster':programa_poster, 'programa_date': programa_date, 'temporada_id': temporada_id, 'page': str(pagina_actual+1)})
        xbmcplugin.addDirectoryItem(handle = addon_handle, url = myurl, listitem = list_item, isFolder=True) 
    else: 
        pass
        
    for i in range(len(liste)):
        myurl = tools.build_url({'action':'play_video', 'capitulo_id':capitulo_id[i]})
        list_item = xbmcgui.ListItem(label=capitulo_titulo[i])
        if tools.getSetting("thumbposter") == 'true':
            list_item.setArt({'thumb': capitulo_thumbnail[i], 'fanart': programa_background, 'clearlogo': programa_logo, 'poster': capitulo_thumbnail[i]})
        else: 
            list_item.setArt({'thumb': capitulo_thumbnail[i], 'fanart': programa_background, 'clearlogo': programa_logo, 'poster': programa_poster})            
        list_item.setInfo('video', {'title': capitulo_titulo[i], 'plot': capitulo_detalle[i], 'aired': capitulo_fecha[i], 'premiered': capitulo_fecha[i], 'duration': capitulo_duracion[i]})
        list_item.setProperty('IsPlayable', 'true')
        xbmcplugin.addDirectoryItem(handle = addon_handle, url = myurl, listitem = list_item, isFolder = False)

    xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_VIDEO_TITLE)
    xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_LABEL_IGNORE_THE)
    xbmcplugin.addSortMethod(addon_handle, xbmcplugin.SORT_METHOD_DATE)
    xbmcplugin.endOfDirectory(addon_handle)                  

    
def play_video(capitulo_id):
    """
    Play a video by the provided path.

    :param path: Fully-qualified video URL
    :type path: str
    """
    # Create a playable item with a path to play.
    #referer = "http://www.rtve.es/alacarta/videos/" + tools.text_to_id(serie_title) +"/"
    #tempurl = "http://www.rtve.es/drmn/embed/video/" + str(capitulo_id)
    url = "http://www.rtve.es/drmn/embed/video/" + str(capitulo_id)
    referer = "http://www.rtve.es/alacarta/videos/" 

    #xbmcgui.Dialog().ok(addonname, str(url))
    try:
        subtitle_url = "http://www.rtve.es/api/videos/" + str(capitulo_id) +"/subtitulos.xml"
        referer = "http://www.rtve.es/alacarta/"
        html = tools.getUrl2(subtitle_url, referer)
        soup = BeautifulSoup(html)
        div = soup.find_all("src")
        subtitle = str(div[0].text)
    except:
        subtitle = ''    
        
    try:
        streams = streamlink.streams(url)
        stream = str(streams['best'].url)
        #xbmcgui.Dialog().ok(addonname, str(stream))
        
        # if ".mp4" in stream: 
            # pattern = "http(.*?)\.mp4"
            # path = tools.findall(pattern, stream, re.DOTALL)[0]
            # path = "http" + path + ".mp4"
        # elif ".avi" in stream: 
            # pattern = "http(.*?)\.avi"
            # path = tools.findall(pattern, stream, re.DOTALL)[0]
            # path = "http" + path + ".avi"
        # elif ".mov" in stream: 
            # pattern = "http(.*?)\.mov"
            # path = tools.findall(pattern, stream, re.DOTALL)[0]
            # path = "http" + path + ".mov"
        play_item = xbmcgui.ListItem(path=stream)
        if subtitle != '' and tools.getSetting("activate_subtitle") == 'true': 
            play_item.setSubtitles([subtitle])
            #play_item.addStreamInfo('subtitle', {'language': 'es'})
        xbmcplugin.setResolvedUrl(addon_handle, True, listitem=play_item)
    except: 
        xbmcgui.Dialog().ok(addonname, "Este video no está disponible. ")
    
    
def router(paramstring):
    ########## yes, I know, this is by far the worst part of the addon...


    # Parse a URL-encoded paramstring to the dictionary of
    # {<parameter>: <value>} elements
    params = dict(parse_qsl(paramstring))
 #   print params

    # Check the parameters passed to the plugin
    if params:
        if params['action'] == 'submenu':
            agr_id_temp = params['agr_id']
            if isanumber(agr_id_temp) == True:
            #if agr_id_temp.isdigit()
                if params['agr_id'] == '42171':
                    list_menu_principal(menu_tipo = 'menu_docu')
                elif params['agr_id'] == '42170':
                    list_menu_principal(menu_tipo = 'menu_series')
                elif params['agr_id'] == '11111':
                    list_menu_principal(menu_tipo = 'menu_az')
                else:
                    list_menu_agrupadores(params['category'], params['agr_id'], params['page'], params['position'])
            else: 
                list_menu_agrupadores(params['category'], params['agr_id'], params['page'], params['position'])
        elif params['action'] == 'menu_general': 
            list_menu_principal(menu_tipo = 'menu_general')
        elif params['action'] == 'agrup2':
            list_menu_agrupadores2(params['programa_id'], params['programa_titulo'], params['programa_description'], params['programa_thumbnail'], params['programa_logo'], params['programa_background'], params['programa_poster'], params['programa_date'])
        elif params['action'] == 'agrup3':
            list_menu_agrupadores3(params['programa_id'], params['programa_titulo'], params['programa_description'], params['programa_thumbnail'], params['programa_logo'], params['programa_background'], params['programa_poster'], params['programa_date'], params['temporada_id'], params['page'])
        elif params['action'] == 'submenu_series': 
            list_menu_episodes1(params['serie_url'], params['serie_id'], params['serie_title'], params['serie_description'])
            #, params['serie_description'])
        elif params['action'] == 'temporada': 
            list_menu_episodes2(params['programa_id'], params['programa_thumbnail'], params['programa_logo'], params['programa_background'], params['programa_poster'], params['flag'], params['capitulo_total'], params['temporada_id'])
        elif params['action'] == 'play_video':
            play_video(params['capitulo_id'])
        else:
            # If the provided paramstring does not contain a supported action
            # we raise an exception. This helps to catch coding errors,
            # e.g. typos in action names.
            raise ValueError('Invalid paramstring: {0}!'.format(paramstring))
                    
    else:
        list_menu_principal(menu_tipo = 'menu_general')

 
def isanumber(inp):
    try:
        val = int(inp)
        return True
    except ValueError:
        return False

if __name__ == '__main__':
    router(sys.argv[2][1:])
